==> fr-aster-9.3.0.1.tbz: aster/STA9.3/bibpyt/Messages/contact3.py <==
#@ MODIF contact3 Messages  DATE 22/04/2008   AUTEUR ABBAS M.ABBAS 
# -*- coding: iso-8859-1 -*-
#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2007  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
# (AT YOUR OPTION) ANY LATER VERSION.                                                  
#                                                                       
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
#                                                                       
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.        
# ======================================================================

def _(x) : return x

cata_msg = {

1 : _("""
Le mot-clef < %(k1)s > est inconnu dans AFFE_CONTACT. Contactez les dveloppeurs.
Note DVP: erreur de cohrence fortran/catalogue. 
"""),

2 : _("""
Le mot-clef < %(k1)s > n'est pas renseign dans AFFE_CONTACT alors qu'il est obligatoire. Contactez les dveloppeurs.
Note DVP: erreur de cohrence fortran/catalogue. 
"""),

3 : _("""
L'option < %(k1)s > ne correspond a aucune option permise par le mot-clef < %(k2)s > dans AFFE_CONTACT. Contactez les dveloppeurs.
Note DVP: erreur de cohrence fortran/catalogue.            
"""),


13 : _("""
L'algorithme de Newton a chou lors de la projection du point de contact de coordonnes
  (%(r1)s,%(r2)s,%(r3)s)
sur la maille %(k1)s.
Erreur de dfinition de la maille ou projection difficile. Contactez l'assistance dans ce dernier cas.  
"""),

14 : _("""
Les vecteurs tangents sont nuls au niveau du projet du point de contact de coordonnes
  (%(r1)s,%(r2)s,%(r3)s) 
sur la maille %(k1)s, 
Erreur de dfinition de la maille ou projection difficile. Contactez l'assistance dans ce dernier cas.
"""),

15 : _("""
La direction d'appariement fixe donnes par le vecteur DIRE_APPA est nulle !
"""),

16 : _("""
Contact mthode continue.
La mthode d'intgration est GAUSS, le champ VALE_CONT n'est pas cr.
"""),

17 : _("""
Contact mthode continue.
Avec un FOND-FISSURE, il est impossible d'utiliser les options suivantes:
- LISSAGE = 'OUI' ou/et
- NORMALE = 'ESCL' ou
- NORMALE = 'MAIT_ESCL'
"""),


23 : _("""
Le vecteur normal est nul au niveau du projet du point de contact de coordonnes
  (%(r1)s,%(r2)s,%(r3)s) 
sur la maille %(k1)s, 
Erreur de dfinition de la maille ou projection difficile. Contactez l'assistance dans ce dernier cas.
"""),

24 : _("""
Il y a plus de trois noeuds exclus sur la maille esclave  %(k1)s  par l'option SANS_GROUP_NO ou SANS_NOEUD.
Supprimer directement la maille esclave de la dfinition de la surface.
"""),

25 : _("""
L'lment port par la maille esclave %(k1)s n'est pas du bon type pour un fond de fissure, elle est de type  %(k2)s 
"""),

26 : _("""
Le vecteur normal est nul au niveau du noeud %(k1)s.
"""),

27 : _("""
Le vecteur normal est nul au niveau de la maille %(k1)s.
"""),

28 : _("""
Le statut du contact a chang %(i1)d fois au point de contact numro %(i2)d sur la maille esclave %(k1)s
Prsence de flip-flop. 
"""),

30 : _("""
Le couple de surfaces de contact %(i1)s pour l'appariement nodal est mal dfini.
Il faut moins de noeuds esclaves que de noeuds maitres pour respecter l'injectivit.
Or ici:
Nombre de noeuds maitres : %(i2)s
Nombre de noeuds esclaves: %(i3)s
Conseil: intervertissez les deux surfaces maitres et esclaves
"""),

31 : _("""
Les vecteurs tangents sont nuls au niveau quand on projette le noeud esclave
%(k1)s sur la maille %(k2)s
"""),

32: _("""
 Le mot-clef DIST_POUT ne fonctionne qu'avec des sections circulaires dfinies dans AFFE_CARA_ELEM.
 """),

33 : _("""
L'erreur suivante est arrive lors du pr-calcul des normales aux noeuds actives par les options
- LISSAGE = 'OUI' ou/et
- NORMALE = 'ESCL' ou
- NORMALE = 'MAIT_ESCL'
"""),

34 : _("""
Echec de l'orthogonalisation du repre tangent construit au niveau du projet du point de contact de coordonnes
  (%(r1)s,%(r2)s,%(r3)s) 
sur la maille %(k1)s, 
Erreur de dfinition de la maille ou projection difficile. Contactez l'assistance dans ce dernier cas.
"""),

35 : _("""
Les vecteurs tangents sont nuls au niveau quand on projette le noeud esclave
%(k1)s sur la noeud maitre %(k2)s
"""),

36 : _("""
La maille %(k1)s est de type 'POI1', ce n'est pas autoris sur une maille maitre. 
"""),


38 : _("""
La maille %(k1)s est de type poutre et sa tangente est nulle.
Vrifiez votre maillage.
"""),

39: _("""
Problme pour rcuprer l'paisseur de la coque pour la maille  %(k1)s
"""),

40: _("""
L'excentricit de la coque pour la maille %(k1)s n'est pas traite
"""),

41: _("""
Problme pour rcuprer l'excentricit de la coque pour la maille  %(k1)s
"""),

42 : _("""
Contact mthodes discrtes. Il y a mlange de mailles quadratiques (TRIA6, TRIA7 ou QUAD9) avec des mailles QUAD8 sur la surface escalve du contact.
On supprime la liaison entre les noeuds sommets et noeud milieu sur le QUAD8.
Il y a risque d'interpntration du noeud milieu pour le QUAD8 considr.
"""),

43 : _("""
La normale que vous avez prdfinie par (VECT_* = 'VECT_Y') n'est pas utilisable en 2D.
Utilisez plutot (ou Dingo) VECT_* = 'FIXE'
"""),


50: _("""
Avec l'option VECT_MAIT = 'FIXE', seule l'option NORMALE = 'MAIT' est possible.
"""),

51: _("""
Avec l'option VECT_MAIT = 'VECT_Y', seule l'option NORMALE = 'MAIT' est possible.
"""),

52: _("""
Avec l'option VECT_ESCL = 'FIXE', seule l'option NORMALE = 'ESCL' est possible.
"""),

53: _("""
Avec l'option VECT_ESCL = 'VECT_Y', seule l'option NORMALE = 'ESCL' est possible.
"""),

54: _("""
Le LISSAGE n'est possible qu'avec des normales automatiques VECT_ESCL='AUTO' et/ou VECT_MAIT='AUTO'.
"""),

54: _("""
Le LISSAGE n'est possible qu'avec des normales automatiques VECT_ESCL='AUTO' et/ou VECT_MAIT='AUTO'.
"""),

60 : _("""
La maille %(k1)s est de type 'POI1', elle ncessite l'utilisation de l'option
NORMALE='FIXE' avec une normale non-nulle. 
"""),

85 : _("""
Contact mthode continue. 
  -> Il y a chec de la boucle contraintes actives lors du traitement
     du contact
  -> Risque & Conseil :
     Vrifier votre maillage ou augmenter ITER_CONT_MAX.
"""),

86 : _("""
Contact mthode continue. 
  -> Il y a convergence force sur boucle contraintes actives lors du traitement
     du contact.
  -> Risque & Conseil :
     La convergence force se dclenche lorsque le problme a du mal  converger. Il y a des risques que le problme 
     soit un peu moins bien trait. Vrifiez bien que vous n'avez pas d'interpntration entre les mailles. S'il y des 
     interpntrations intempestives, tentez de dcouper plus finement en temps votre problme.
"""),

87 : _("""
Contact mthode continue. 
  -> Il y a convergence force sur boucle seuil frottement lors du traitement du
     contact.
  -> Risque & Conseil :
     La convergence force se dclenche lorsque le problme a du mal  converger. Il y a des risques que le problme 
     soit un peu moins bien trait. La condition de frottement de Coulomb est peut etre mal prise en compte. Risque de 
     rsultats faux sur les forces d'adhrence. Essayez de dcouper plus finement en temps votre problme.
"""),

88 : _("""
Contact mthode continue. 
  -> Il y a convergence force sur boucle de gomtrie lors du traitement du
     contact.
  -> Risque & Conseil :
     La convergence force se dclenche lorsque le problme a du mal  converger
     lors de grands glissements relatifs entre deux surfaces de contact.
     Il y a des risques que le problme soit un peu moins bien trait.
     Vrifiez bien que vous n'avez pas d'interpntration entre les mailles.
     S'il y des interpntrations intempestives, tentez de dcouper plus finement en temps votre problme.
"""),

}

==> fr-aster-9.4.0.2.tbz: aster/STA9.4/bibpyt/Messages/contact3.py <==
#@ MODIF contact3 Messages  DATE 23/09/2008   AUTEUR ABBAS M.ABBAS 
# -*- coding: iso-8859-1 -*-
#            CONFIGURATION MANAGEMENT OF EDF VERSION
# ======================================================================
# COPYRIGHT (C) 1991 - 2007  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY  
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY  
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR     
# (AT YOUR OPTION) ANY LATER VERSION.                                                  
#                                                                       
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT   
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF            
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU      
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.                              
#                                                                       
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE     
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,         
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.        
# ======================================================================

def _(x) : return x

cata_msg = {

1 : _("""
Le mot-clef < %(k1)s > est inconnu dans AFFE_CONTACT. Contactez les dveloppeurs.
Note DVP: erreur de cohrence fortran/catalogue. 
"""),

2 : _("""
Le mot-clef < %(k1)s > n'est pas renseign dans AFFE_CONTACT alors qu'il est obligatoire. Contactez les dveloppeurs.
Note DVP: erreur de cohrence fortran/catalogue. 
"""),

3 : _("""
L'option < %(k1)s > ne correspond a aucune option permise par le mot-clef < %(k2)s > dans AFFE_CONTACT. Contactez les dveloppeurs.
Note DVP: erreur de cohrence fortran/catalogue.            
"""),


13 : _("""
L'algorithme de Newton a chou lors de la projection du point de contact de coordonnes
  (%(r1)s,%(r2)s,%(r3)s)
sur la maille %(k1)s.
Erreur de dfinition de la maille ou projection difficile. Contactez l'assistance dans ce dernier cas.  
"""),

14 : _("""
Les vecteurs tangents sont nuls au niveau du projet du point de contact de coordonnes
  (%(r1)s,%(r2)s,%(r3)s) 
sur la maille %(k1)s, 
Erreur de dfinition de la maille ou projection difficile. Contactez l'assistance dans ce dernier cas.
"""),

15 : _("""
La direction d'appariement fixe donnes par le vecteur DIRE_APPA est nulle !
"""),

16 : _("""
Contact mthode continue.
La mthode d'intgration n'est pas NOEUD, le champ VALE_CONT n'est pas cr.
"""),

17 : _("""
Contact mthode continue.
Avec un FOND-FISSURE, il est impossible d'utiliser les options suivantes:
- LISSAGE = 'OUI' ou/et
- NORMALE = 'ESCL' ou
- NORMALE = 'MAIT_ESCL'
"""),


23 : _("""
Le vecteur normal est nul au niveau du projet du point de contact de coordonnes
  (%(r1)s,%(r2)s,%(r3)s) 
sur la maille %(k1)s, 
Erreur de dfinition de la maille ou projection difficile. Contactez l'assistance dans ce dernier cas.
"""),

25 : _("""
L'lment port par la maille esclave %(k1)s n'est pas du bon type pour un fond de fissure, elle est de type  %(k2)s 
"""),

26 : _("""
Le vecteur normal est nul au niveau du noeud %(k1)s.
"""),

27 : _("""
Le vecteur normal est nul au niveau de la maille %(k1)s.
"""),

28 : _("""
Le statut du contact a chang %(i1)d fois au point de contact numro %(i2)d sur la maille esclave %(k1)s
Prsence de flip-flop. 
"""),

29 : _("""
Nom de la maille : %(k1)s 
"""),

30 : _("""
Le couple de surfaces de contact %(i1)s pour l'appariement nodal est mal dfini.
Il faut moins de noeuds esclaves que de noeuds maitres pour respecter l'injectivit.
Or ici:
Nombre de noeuds maitres : %(i2)s
Nombre de noeuds esclaves: %(i3)s
Conseil: intervertissez les deux surfaces maitres et esclaves
"""),

31 : _("""
Les vecteurs tangents sont nuls au niveau quand on projette le noeud esclave
%(k1)s sur la maille %(k2)s
"""),

32: _("""
 Le mot-clef DIST_POUT ne fonctionne qu'avec des sections circulaires dfinies dans AFFE_CARA_ELEM.
 """),

33 : _("""
L'erreur suivante est arrive lors du pr-calcul des normales aux noeuds actives par les options
- LISSAGE = 'OUI' ou/et
- NORMALE = 'ESCL' ou
- NORMALE = 'MAIT_ESCL'
"""),

34 : _("""
Echec de l'orthogonalisation du repre tangent construit au niveau du projet du point de contact de coordonnes
  (%(r1)s,%(r2)s,%(r3)s) 
sur la maille %(k1)s, 
Erreur de dfinition de la maille ou projection difficile. Contactez l'assistance dans ce dernier cas.
"""),

35 : _("""
Les vecteurs tangents sont nuls au niveau quand on projette le noeud esclave
%(k1)s sur la noeud maitre %(k2)s
"""),

36 : _("""
La maille %(k1)s est de type 'POI1', ce n'est pas autoris sur une maille maitre. 
"""),


38 : _("""
La maille %(k1)s est de type poutre et sa tangente est nulle.
Vrifiez votre maillage.
"""),

39: _("""
Problme pour rcuprer l'paisseur de la coque pour la maille  %(k1)s
"""),

40: _("""
L'excentricit de la coque pour la maille %(k1)s n'est pas traite
"""),

41: _("""
Problme pour rcuprer l'excentricit de la coque pour la maille  %(k1)s
"""),

42 : _("""
Contact mthodes discrtes. Il y a mlange de mailles quadratiques (TRIA6, TRIA7 ou QUAD9) avec des mailles QUAD8 sur la surface escalve du contact.
On supprime la liaison entre les noeuds sommets et noeud milieu sur le QUAD8.
Il y a risque d'interpntration du noeud milieu pour le QUAD8 considr.
"""),

43 : _("""
La normale que vous avez prdfinie par (VECT_* = 'VECT_Y') n'est pas utilisable en 2D.
Utilisez plutot (ou Dingo) VECT_* = 'FIXE'
"""),


50: _("""
Avec l'option VECT_MAIT = 'FIXE', seule l'option NORMALE = 'MAIT' est possible.
"""),

51: _("""
Avec l'option VECT_MAIT = 'VECT_Y', seule l'option NORMALE = 'MAIT' est possible.
"""),

52: _("""
Avec l'option VECT_ESCL = 'FIXE', seule l'option NORMALE = 'ESCL' est possible.
"""),

53: _("""
Avec l'option VECT_ESCL = 'VECT_Y', seule l'option NORMALE = 'ESCL' est possible.
"""),

54: _("""
Le LISSAGE n'est possible qu'avec des normales automatiques VECT_ESCL='AUTO' et/ou VECT_MAIT='AUTO'.
"""),

54: _("""
Le LISSAGE n'est possible qu'avec des normales automatiques VECT_ESCL='AUTO' et/ou VECT_MAIT='AUTO'.
"""),

60 : _("""
La maille %(k1)s est de type 'POI1', elle ncessite l'utilisation de l'option
NORMALE='FIXE' avec une normale non-nulle. 
"""),

85 : _("""
Contact mthode continue. 
  -> Il y a chec de la boucle contraintes actives lors du traitement
     du contact
  -> Risque & Conseil :
     Vrifier votre maillage ou augmenter ITER_CONT_MAX.
"""),

86 : _("""
Contact mthode continue. 
  -> Il y a convergence force sur boucle contraintes actives lors du traitement
     du contact.
  -> Risque & Conseil :
     La convergence force se dclenche lorsque le problme a du mal  converger. Il y a des risques que le problme 
     soit un peu moins bien trait. Vrifiez bien que vous n'avez pas d'interpntration entre les mailles. S'il y des 
     interpntrations intempestives, tentez de dcouper plus finement en temps votre problme.
"""),

87 : _("""
Contact mthode continue. 
  -> Il y a convergence force sur boucle seuil frottement lors du traitement du
     contact.
  -> Risque & Conseil :
     La convergence force se dclenche lorsque le problme a du mal  converger. Il y a des risques que le problme 
     soit un peu moins bien trait. La condition de frottement de Coulomb est peut etre mal prise en compte. Risque de 
     rsultats faux sur les forces d'adhrence. Essayez de dcouper plus finement en temps votre problme.
"""),

88 : _("""
Contact mthode continue. 
  -> Il y a convergence force sur boucle de gomtrie lors du traitement du
     contact.
  -> Risque & Conseil :
     La convergence force se dclenche lorsque le problme a du mal  converger
     lors de grands glissements relatifs entre deux surfaces de contact.
     Il y a des risques que le problme soit un peu moins bien trait.
     Vrifiez bien que vous n'avez pas d'interpntration entre les mailles.
     S'il y des interpntrations intempestives, tentez de dcouper plus finement en temps votre problme.
"""),

}
